Skip to contents

Returns the function currently used to draw term figures. If no custom function has been set, returns tabulergm_default_plotfun().

Usage

tabulergm_get_plotfun()

Value

A function (the active plot function).