Skip to contents

Restores the default column layout of a table returned by tabulergm_table(). This is useful after applying another table style in a pipe.

Usage

with_style_plain(x)

Arguments

x

A data frame or knitr_kable object returned by tabulergm_table() or one of the with_style_*() helpers.

Value

An object in the same requested output format as x.

Examples

tbl <- tabulergm_table(~ edges)
tbl |> with_style_name_over_formula() |> with_style_plain()
#>    term
#> 1 edges
#>                                                                                                         figure
#> 1 /tmp/RtmpRs97L3/tabulergm-4ec940654adcc485b27f39ca7dd20ef2-b6f3c9a3a81099857159db04549de0da-4-undirected.png
#>                 math
#> 1 \\sum_{i<j} y_{ij}
#>                                                                                                                                           description
#> 1 Counts the ties present in the network. Acts as the baseline density term, playing the role an intercept plays in a regression model. (holland1981)