Returns the function currently used to draw term figures.
If no custom function has been set, returns
tabulergm_default_plotfun().
Returns the function currently used to draw term figures.
If no custom function has been set, returns
tabulergm_default_plotfun().